import request from '@/utils/request'
import { parseStrEmpty } from "@/utils/goldenwater";

export function listBidCaller(query) {
  return request({ url: '/pms/bidCaller/list', method: 'get', params: query })
}

export function getBidCaller(ivtId) {
  return request({ url: '/pms/bidCaller/' + parseStrEmpty(ivtId), method: 'get' })
}

export function addBidCaller(data) {
  return request({ url: '/pms/bidCaller', method: 'post', data: data })
}

export function updateBidCaller(data) {
  return request({ url: '/pms/bidCaller', method: 'put', data: data })
}

export function delBidCaller(ivtId) {
  return request({ url: '/pms/bidCaller/' + ivtId, method: 'delete' })
}

export function listBidTender(query) {
  return request({ url: '/pms/bidTender/list', method: 'get', params: query })
}

export function getBidTender(bidId) {
  return request({ url: '/pms/bidTender/' + parseStrEmpty(bidId), method: 'get' })
}

export function addBidTender(data) {
  return request({ url: '/pms/bidTender', method: 'post', data: data })
}

export function updateBidTender(data) {
  return request({ url: '/pms/bidTender', method: 'put', data: data })
}

export function delBidTender(bidId) {
  return request({ url: '/pms/bidTender/' + bidId, method: 'delete' })
}
